<?php



/**
 * Is executed defore an entity is saved by the channels service
 *
 * @param string $entity_type The type of the entity (node or taxonomy_term)
 * @param object $entity The entity object
 */
function hook_channels_client_before_entity_save($entity_type, $entity) {}

/**
 * Is executed after an entity is saved by the channels service
 *
 * @param string $entity_type The type of the entity (node or taxonomy_term)
 * @param object $entity The entity object
 */
function hook_channels_client_after_entity_save($entity_type, $entity) {}

/**
 * Is executed defore an entity is deleted by the channels service
 *
 * @param string $entity_type The type of the entity (node or taxonomy_term)
 * @param int $entity_id The entity ID
 * @return bool $ret
 *
 *    Return FALSE to delete the entity
 *    Return TRUE to skip the entity deletion
 */
function hook_channels_client_before_entity_delete($entity_type, $entity_id) {}

/**
 * Is executed after an entity is deleted by the channels service
 *
 * @param string $entity_type The type of the entity (node or taxonomy_term)
 * @param int $entity_id The entity ID
 */
function hook_channels_client_after_entity_delete($entity_type, $entity_id) {}


/**
 * Is executed defore an file is saved by the channels service
 *
 * @param object $file Object representation of a file
 *
 * Example:
 * stdClass Object
 *  (
 *             [fid] => 18
 *             [uid] => 1
 *             [filename] =>
 *             [uri] => public://field/image/imagefield_nUslG8.png
 *             [filemime] => image/png
 *             [filesize] => 1303
 *             [status] => 1
 *             [timestamp] => 1295884715
 *  )
 *
 * @param int $entity_id Entity ID
 * @param string $field_name The field's name the file is attached
 */
function hook_channels_client_before_file_save($file, $entity_id, $field_name) {}

/**
 * Is executed after a file is saved by the channels service
 *
 * @param object $file Object representation of a file
 *
 * Example:
 * stdClass Object
 *  (
 *             [fid] => 18
 *             [uid] => 1
 *             [filename] =>
 *             [uri] => public://field/image/imagefield_nUslG8.png
 *             [filemime] => image/png
 *             [filesize] => 1303
 *             [status] => 1
 *             [timestamp] => 1295884715
 *  )
 *
 * @param int $entity_id Entity ID
 * @param string $field_name The field's name the file is attached
 *
 */
function hook_channels_client_after_file_save($file, $entity_id, $field_name) {}

/**
 *
 * Alter a node before the client save it (convert a drupal 7 node to a drupal 6 one)
 *
 * @param array $fields List of the node's fields received by the service
 * @param object $node Object representation of a node
 */
function hook_channels_client_node_alter($fields, $node) {}

/**
 *
 * Alter a taxonomy term before the client save it (convert a drupal 7 term to a drupal 6 one)
 *
 * @param array $fields List of the term's fields received by the service
 * @param array $term Array representation of a term
 */
function hook_channels_client_taxonomy_term_alter($fields, $term) {}

/**
 *
 *  Is executed before saving the identifiers' map for a given entity
 *
 * @param string $local_id Local identifier of the entity
 * @param int $external_id External identifier of the entity
 * @param string $type The type of the entity (node | taxonomy_term)
 */
function hook_channels_client_presave_map($local_id, $external_id, $type) {}

/**
 *
 *  Is executed when the identifiers' map for a given entity is saved
 *
 * @param string $local_id Local identifier of the entity
 * @param int $external_id External identifier of the entity
 * @param string $type The type of the entity (node | taxonomy_term)
 */
function hook_channels_client_save_map($local_id, $external_id, $type) {}

/**
 * Is executed when the identifiers' map for the given local entity is removed
 *
 * @param int $local_id Local node id
 * @param string $type Type of entity (node, taxonomy_term...)
 */
function hook_channels_client_delete_map($local_id, $type) {}